@@ -362,7 +362,7 @@ class PortfolioByPartyDetailed(Report):
                 elif invoice.state == 'validated':
                     invoice.state = 'Validada'
                 elif invoice.state == 'posted':
-                    invoice.state = 'Registrada'
+                    invoice.state = 'Contabilizada'
                 new_invoices.append(invoice)
 
             party.invoices = new_invoices
