@@ -6,8 +6,10 @@ from trytond.pool import PoolMeta, Pool
 from trytond.pyson import Eval
 from trytond.wizard import Wizard, StateTransition
 from trytond.transaction import Transaction
+from trytond.modules.company import CompanyReport
 
-__all__ = ['Invoice', 'InvoiceForceDrawStart', 'InvoiceForceDraw']
+__all__ = ['Invoice', 'InvoiceForceDrawStart', 'InvoiceForceDraw', 
+        'EquivalentInvoice']
 __metaclass__ = PoolMeta
 
 
@@ -45,3 +47,18 @@ class InvoiceForceDraw(Wizard):
         cursor.execute(query % str(invoice.move.id))
 
         return 'end'
+
+
+class EquivalentInvoice(CompanyReport):
+    'Equivalent Invoice'
+    __name__ = 'account.invoice.equivalent'
+
+    @classmethod
+    def __setup__(cls):
+        super(EquivalentInvoice, cls).__setup__()
+
+    @classmethod
+    def parse(cls, report, objects, data, localcontext=None):
+        localcontext['company'] = Transaction().context.get('company')
+        return super(EquivalentInvoice, cls).parse(report,
+                objects, data, localcontext)
